@@ -24,19 +24,6 @@ logger.setLevel(logging.INFO)
 logging.basicConfig()
 
 
-# HIVE chain config
-custom_chains = {
-    'HIVE': dict(
-        chain_assets=[
-            dict(asset='@@000000013', id=0, precision=3, symbol='HBD'),
-            dict(asset='@@000000021', id=1, precision=3, symbol='HIVE'),
-            dict(asset='@@000000037', id=2, precision=6, symbol='VESTS')
-        ],
-        chain_id="0" * int(256 / 4), min_version='0.23.0', prefix='STM'
-    )
-}
-
-
 class Transmitter:
 
     def __init__(self, config_file, action=None, signing_key=None,
@@ -108,7 +95,7 @@ class Transmitter:
             "https://api.hive.blog",
             "https://api.hivekings.com",
             "https://anyx.io"]
-        steem = Steem(node=nodes, keys=keys, custom_chains=custom_chains)
+        steem = Steem(node=nodes, keys=keys)
 
         return steem
 
@@ -194,12 +181,12 @@ class Transmitter:
                 # sbd_exchange_rate has a special case
                 # where it's value is a dict
                 # instead of a straight string or integer.
-                key = "sbd_exchange_rate"
+                key = "hbd_exchange_rate"
                 val = _property["sbd_exchange_rate"]
             else:
                 key, val = _property.split("=")
             if isinstance(_property, dict):
-                props["sbd_exchange_rate"] = val
+                props["hbd_exchange_rate"] = val
             else:
                 try:
                     props[key] = int(val)
@@ -223,11 +210,11 @@ class Transmitter:
             logger.info(f"Prices after outlier detection: {filtered_prices}")
             prices = filtered_prices
         average_price = get_average_price(prices)
-        base = Amount(average_price, "SBD")
+        base = Amount(average_price, "HBD", steem_instance=self.steem)
         quote = Amount(
-            round(float(1) / float(self.peg_multiplier), 3), "STEEM")
+            round(float(1) / float(self.peg_multiplier), 3), "HIVE")
         properties = [{
-            "sbd_exchange_rate": {
+            "bd_exchange_rate": {
                 "base": base, "quote": quote}
         }]
         logger.info(f"Base price: {base}, Quote price: {quote}")
